=====
Usage
=====

To use ksfest in a project::

    from ksfest import ksfest

    ksf= ksfest.ks_fest()

    gks= ksfest.ks_fest()
    
    ks_pandas= gks.get_ks(iris, var_dim='species', sample=0.1, na_number=-1)


